<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>ConfigDialog</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialog.ui" line="14"/>
        <source>Dialog</source>
        <translation>Диалог</translation>
    </message>
</context>
<context>
    <name>LXQt::MessageBox</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="76"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::NotificationPrivate</name>
    <message>
        <location filename="../lxqtnotification.cpp" line="161"/>
        <source>Notifications Fallback</source>
        <translation>Резервный вариант уведомлений</translation>
    </message>
</context>
<context>
    <name>LXQt::PowerManager</name>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="108"/>
        <source>Hibernate</source>
        <translation>Спящий режим</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="115"/>
        <source>Suspend</source>
        <translation>Ждущий режим</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="122"/>
        <source>Reboot</source>
        <translation>Перезагрузить</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="129"/>
        <source>Shutdown</source>
        <translation>Выключить компьютер</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="136"/>
        <source>Logout</source>
        <translation>Завершить сеанс</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="148"/>
        <source>LXQt Session Suspend</source>
        <translation>Ждущий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="149"/>
        <source>Do you want to really suspend your computer?&lt;p&gt;Suspends the computer into a low power state. System state is not preserved if the power is lost.</source>
        <translation>Перевести компьютер в ждущий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотребления. В случае отключения питания состояние системы будет потеряно.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="158"/>
        <source>LXQt Session Hibernate</source>
        <translation>Спящий режим сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="159"/>
        <source>Do you want to really hibernate your computer?&lt;p&gt;Hibernates the computer into a low power state. System state is preserved if the power is lost.</source>
        <translation>Перевести компьютер в спящий режим?&lt;p&gt;Переводит компьютер в режим низкого энергопотребления. Состояние системы будет сохранено при отключении питания.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="168"/>
        <source>LXQt Session Reboot</source>
        <translation>Перезагрузка сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="169"/>
        <source>Do you want to really restart your computer? All unsaved work will be lost...</source>
        <translation>Перезагрузить компьютер? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="178"/>
        <source>LXQt Session Shutdown</source>
        <translation>Выключение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="179"/>
        <source>Do you want to really switch off your computer? All unsaved work will be lost...</source>
        <translation>Выключить компьютер? Вся несохранённая работа будет потеряна…</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="188"/>
        <source>LXQt Session Logout</source>
        <translation>Завершение сеанса LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="189"/>
        <source>Do you want to really logout? All unsaved work will be lost...</source>
        <translation>Завершить сеанс? Все несохранённые изменения в документах будут потеряны...</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>LXQt Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением LXQt</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="197"/>
        <source>Hibernate failed.</source>
        <translation>Ошибка перехода в спящий режим.</translation>
    </message>
    <message>
        <location filename="../lxqtpowermanager.cpp" line="202"/>
        <source>Suspend failed.</source>
        <translation>Ошибка перехода в ждущий режим.</translation>
    </message>
</context>
<context>
    <name>LXQt::ScreenSaver</name>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="161"/>
        <source>Failed to run  &quot;%1&quot;. Ensure you have a locker/screensaver compatible with xdg-screensaver installed and running.</source>
        <translation>Не удалось запустить «%1». Убедитесь, что блокировщик/хранитель экрана совместим с установленным и запускаемым xdg-screensaver.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="165"/>
        <source>Failed to run  &quot;%1&quot;. Ensure the specified locker/screensaver is installed and running.</source>
        <translation>Не удалось запустить «%1». Убедитесь, что указанный блокировщик/хранитель экрана установлен и корректно запускается.</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="247"/>
        <source>Lock Screen</source>
        <translation>Блокировка экрана</translation>
    </message>
    <message>
        <location filename="../lxqtscreensaver.cpp" line="156"/>
        <source>Screen Saver Error</source>
        <translation>Ошибка хранителя экрана</translation>
    </message>
</context>
<context>
    <name>QCoreApplication</name>
    <message>
        <location filename="../configdialog/lxqtconfigdialogcmdlineoptions.cpp" line="47"/>
        <source>Choose the page to be shown.</source>
        <translation>Выберите страницу, которая будет показана.</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="87"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="137"/>
        <source>Power Manager Error</source>
        <translation>Ошибка управления энергопотреблением</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="88"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="138"/>
        <source>QDBusInterface is invalid</source>
        <translation>Неправильный интерфейс доступа к шине DBus</translation>
    </message>
    <message>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="102"/>
        <location filename="../lxqtpower/lxqtpowerproviders.cpp" line="152"/>
        <source>Power Manager Error (D-BUS call)</source>
        <translation>Ошибка управления энергопотреблением (вызов D-BUS)</translation>
    </message>
</context>
</TS>
